#==============================================================================
# package      DE_EPAGES::GoogleAdWords::UI::Shop
# base         DE_EPAGES::Order::UI::Shop
# state        private
#==============================================================================
package DE_EPAGES::GoogleAdWords::UI::Shop;
use base DE_EPAGES::Presentation::UI::Object;

use strict;

use DE_EPAGES::Core::API::Error qw ( Error ExistsError GetError);
use DE_EPAGES::GoogleAdWords::API::GoogleAdWords qw ( ApplyPromotionCodeToShop FormatAdwordsTrackingCode );
use DE_EPAGES::Trigger::API::Trigger qw ( TriggerHook );

#==============================================================================
# push a google promotion code to our shop
#==============================================================================
sub Generate {
    my $self = shift;
    my ($Servlet) = @_;
    my $Shop = $Servlet->object;

    ApplyPromotionCodeToShop($Shop);
}

sub Save {
    my $self = shift;
    my ($Servlet) = @_;

    # EPG-23378 GoogleAdWordsHTMLCode
    my $hValues = $Servlet->form->form($Servlet->object, 'SaveGoogleAdwords');
    my $GoogleAdwordsHTMLCode = $hValues->{'GoogleAdWordsHTMLCode'};
    my $FormattedAdwordsCode = FormatAdwordsTrackingCode($GoogleAdwordsHTMLCode);

    $Servlet->object->set({'GoogleAdWordsHTMLCode' => $FormattedAdwordsCode});

    return;
}

sub UnitySave {
    my $self = shift;
    my ($Servlet) = @_;

    eval {
        $self->SUPER::Save($Servlet);
    };
    if (ExistsError()) {
        my $Error = GetError();
        if ($Error->code eq 'NoGoogleAdWordsIDFound') {
            $Servlet->form->executeFormError({
                'Name'       => 'GoogleAdWordsHTMLCode',
                'Reason'     => 'NoIDFound',
            });
        } else {
            Error($Error);
        }
    }
}

sub UnityMBOViewGoogleAdWords {
    my $self = shift;
    my ($Servlet) = @_;

    # trigger hook to allow the adding of context sensitive apps
    TriggerHook('UI_Shop_UnityViewGoogleAdWords', { 'Servlet' => $Servlet });

    return $self->SUPER::View($Servlet);
}

1;
