#!perl -w
use Test::More tests => 18;

use strict;
use File::Temp qw( tempdir );
use DE_EPAGES::Core::API::SystemCommand qw(ShellCommand);
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::File qw(DeleteDirectory);

RunScript( Debug => 1, Sub => sub {

    my $TempDir = tempdir();
    local $ENV{EPAGES_PATCHES} = $TempDir;
    my $Env = $^O eq 'linux' ? ". $ENV{PERL} ;" : undef;
    my $Perl = $^O eq 'linux' ? "EPAGES_PATCHES=$TempDir $^X" : $^X;

    my $AddLanguages = "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/Installer/Scripts/addLanguages.pl";

    ShellCommand( "$Env $Perl $AddLanguages -nooutput -get 6.12 -lang da", {print => 1});
    ok(-f _Dictionary($TempDir, '6.12.0', 'da'), 'perl addLanguages.pl -get 6.12 -lang da (6.12.0)');
    ok(-f _Dictionary($TempDir, '6.12.1', 'da'), 'perl addLanguages.pl -get 6.12 -lang da (6.12.1)');
    ok(-f _Dictionary($TempDir, '6.12.2', 'da'), 'perl addLanguages.pl -get 6.12 -lang da (6.12.2)');
    ok(-f _Dictionary($TempDir, '6.12.3', 'da'), 'perl addLanguages.pl -get 6.12 -lang da (6.12.3)');
    ShellCommand( "$Env $Perl $AddLanguages -nooutput -get 6.13.1 -lang any");
    ok(-f _Dictionary($TempDir, '6.13.1', 'ca'), 'perl addLanguages.pl -get 6.13.1 -lang any (ca)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'cs'), 'perl addLanguages.pl -get 6.13.1 -lang any (cs)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'en-US'), 'perl addLanguages.pl -get 6.13.1 -lang any (en-US)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'es'), 'perl addLanguages.pl -get 6.13.1 -lang any (es)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'fi'), 'perl addLanguages.pl -get 6.13.1 -lang any (fi)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'fr'), 'perl addLanguages.pl -get 6.13.1 -lang any (fr)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'it'), 'perl addLanguages.pl -get 6.13.1 -lang any (it)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'nl'), 'perl addLanguages.pl -get 6.13.1 -lang any (nl)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'no'), 'perl addLanguages.pl -get 6.13.1 -lang any (no)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'pt'), 'perl addLanguages.pl -get 6.13.1 -lang any (pt)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'ru'), 'perl addLanguages.pl -get 6.13.1 -lang any (ru)');
    ok(-f _Dictionary($TempDir, '6.13.1', 'sv'), 'perl addLanguages.pl -get 6.13.1 -lang any (sv)');
    ShellCommand( "$Env EPAGES_LANGUAGES='it pt' $Perl $AddLanguages -nooutput -get 6.17.20");
    ok(-f _Dictionary($TempDir, '6.17.20', 'it'), 'EPAGES_LANGUAGES="it pt" perl addLanguages.pl -get (it)');
    ok(-f _Dictionary($TempDir, '6.17.20', 'pt'), 'EPAGES_LANGUAGES="it pt" perl addLanguages.pl -get (pt)');

    DeleteDirectory($TempDir, {'recursive' => 1});
});

sub _Dictionary {
    my ($TempDir, $Version, $Lang) = @_;

    my ($Main, $Sub, $Level) = $Version =~ /^([^.]+)\.([^.]+)\.([^.]+)/;
    my $LangVersion = "$Main${Sub}p$Level";

    return "$TempDir/LanguagePacks/langpack-$Lang-epages$LangVersion/Cartridges/DE_EPAGES/Dictionary/Templates/Dictionary.$Lang.xml"
}
