#========================================================================================
# package      DE_EPAGES::RemoteSearch::Hooks::TaxMatrix.pm
# state        private
#----------------------------------------------------------------------------------------
# description  Brutto price calculation is handled by ePagesJ. If TaxMratix changes normally
#               all product prices changes and the shop must be reindexed.
#========================================================================================
package DE_EPAGES::RemoteSearch::Hooks::TaxMatrix;

use strict;

use DE_EPAGES::Object::API::Factory qw ( LoadObject );
use DE_EPAGES::RemoteSearch::API::AttributeModifiedCheck qw ( RunIfModified );
use DE_EPAGES::RemoteSearch::API::RemoteSearchImpl qw ( RunIfRemoteSearchInitialized );
use DE_EPAGES::Tax::API::Table::TaxRate qw ( GetInfoTaxRate );

sub OnBeforeUpdateTaxRate {
    my ($hParam) = @_;
    my $Shop = LoadObject($hParam->{TaxAreaID})->getSite;
    return unless ($Shop->instanceOf('Shop'));

    RunIfModified(
        sub { return GetInfoTaxRate($hParam->{'TaxAreaID'},$hParam->{'TaxClassID'})},
        ['Rate'], $hParam, undef, ['Float'],
        sub {
            _reindexShop($Shop);
        }
    )
}

sub OnDeleteTaxMatrix {
    my ($hParam) = @_;
    my $Shop = $hParam->{'Object'}->getSite;
    return unless ($Shop->instanceOf('Shop'));
    _reindexShop($Shop);
    return;
}

sub OnInsertTaxMatrix {
    my ($hParam) = @_;
    my $Shop = $hParam->{'Object'}->getSite;
    return unless ($Shop->instanceOf('Shop'));
    _reindexShop($Shop);
    return;
}

sub OnUpdateTaxMatrix {
    my ($hParam) = @_;
    my $Shop = $hParam->{'Object'}->getSite;
    return unless ($Shop->instanceOf('Shop'));
    _reindexShop($Shop);
    return;
}

sub _reindexShop {
    my ($Shop) = @_;
    RunIfRemoteSearchInitialized($Shop, sub {
        my ($Search) = @_;
        $Search->initialize();
    });
    return;
}

1;